# text to audio file converter by python
I make a Python based light weight Computer Anti-Virus. You can you this project, by installing this Anti - Virus package by running those commands that embedded below.

To run this project , first run :-

        pip install comantivirus

Now, for use this package, you need some packages.

to use thease package, install this packages first :-

        pip install time

        pip install os

        pip install pyautogui

after run those commands, run command :-

make a file in anyware in desktop. ex; 'xyz.py'.

after making thease file, insert this line to the file :-

        from comantivirus import start

then, call the main function via :- 

        start()

then a GUI has open.

now follow the GUI instructions and convert a text massage into a audio file & save in your desktop.

 * You can download & install this project for free but to use this package, you need Access key. To get Access key, visit this link to buy Access Key :-

                https://ankansaha.web.app/html/buyaccesskey.html
